Django postgres age filter
==========================

Helper to add age based filtering to django, leveraging postgresql's
`date functions <http://www.postgresql.org/docs/9.3/static/functions-datetime.html>`_


Warning
-------

This does make use of django internals, which may change between versions. Make
sure you are using a version of ``django_pg_filter`` that matches your version of
``django``.


License
-------

MIT. See LICENSE for details.
